/**
 * Based on mathlive,see more: https://cortexjs.io/mathlive/
 */
import type { MathfieldElement as MathfieldElementType } from 'mathlive';
import '../../../theme/panelview.css';
interface PanelCommand {
    editor: {
        t: (text: string) => string;
    };
    value: string | undefined;
    off: (event: 'mounted' | 'refocus' | 'reopen') => void;
    on(event: 'mounted', callback: () => void): void;
    on(event: 'refocus' | 'reopen', callback: (_: unknown, equation: string) => void): void;
    fire(event: 'close'): void;
    fire(event: 'insert', equation: string): void;
}
export default class PanelView {
    constructor();
    equation: string;
    destroy: () => void;
    mount(hookContainer: HTMLElement): void;
    private textForInsertButton;
    getTextForInsertButton(): string;
    setTextForInsertButton(text: string): void;
    private textForPanelHeader;
    getTextForPanelHeader(): string;
    setTextForPanelHeader(text: string): void;
    private textForCloseButton;
    getTextForCloseButton(): string;
    setTextForCloseButton(text: string): void;
    private spawnPanelOnLeft;
    private spawnPanelOnTop;
    /**
     * Get if the panel will spawn on the left side.
     * @returns {boolean} Return true if the panel will spawn on the left side
     */
    getSpawnPanelOnLeft(): boolean;
    /**
     * Set the panel to spawn on the left side.
     * @param {boolean} value - The value to set the panel to spawn on the left side
     */
    setSpawnPanelOnLeft(value: boolean): void;
    /**
     * Get if the panel will spawn on top.
     * @returns {boolean} Return true if the panel will spawn on top
     */
    getSpawnPanelOnTop(): boolean;
    /**
     * Set the panel to spawn on top.
     * @param {boolean} value - The value to set the panel to spawn on top
     */
    setSpawnPanelOnTop(value: boolean): void;
    render(translate: PanelCommand['editor']['t']): HTMLElement;
    setMathfieldElementConfig(): void;
}
export declare class FormulaView {
    constructor(props?: FormulaView['props']);
    destroy: () => void;
    hookContainer: HTMLElement | null;
    props?: {
        onMathTexClick?: (equation: string, interceptor?: {
            before?: (mathField: MathfieldElementType) => Promise<void>;
            after?: (mathField: MathfieldElementType) => Promise<void>;
            customInsert?: (mathField: MathfieldElementType) => void;
        }) => void;
        onFormulaTabClick?: (key: string) => void;
    };
    activeTabKey: string;
    formulaTabs: {
        key: string;
        latexIcons: string[];
    }[];
    formulaMap: {
        [key: string]: Array<Array<string>>;
    };
    insertInterceptors: Array<{
        equations: Array<string>;
        before?: (mathField: MathfieldElementType) => Promise<void>;
        after?: (mathField: MathfieldElementType) => Promise<void>;
        customInsert?: (mathField: MathfieldElementType) => void;
    }>;
    mount(hookContainer: FormulaView['hookContainer']): void;
    remount(): void;
    render(): HTMLElement;
    latexIconMarkupMap: {
        [key: string]: string;
    } | undefined;
    getLatexIconMarkupMap(): FormulaView['latexIconMarkupMap'];
    latexIconConvertInterceptorMap: {
        [key: string]: {
            before?: (latex: string) => string;
            after?: (markup: string) => string;
        };
    };
    getConvertToIconMarkupLatex(): Array<{
        latex: string;
        iconLatex: string;
    }>;
}
export {};
